Memory

Trait Memory 

pub trait Memory:
    Debug
    + Send
    + Sync {
    // Required methods
    fn ty(&self) -> MemoryType;
    fn style(&self) -> &MemoryStyle;
    fn size(&self) -> Pages;
    fn grow(&self, delta: Pages) -> Result<Pages, MemoryError>;
    fn vmmemory(&self) -> NonNull<VMMemoryDefinition>;
}
Trait for implementing Wasm Memory used by Wasmer.

Required Methods

fn ty(&self) -> MemoryType

Returns the memory type for this memory.

fn style(&self) -> &MemoryStyle

Returns the memory style for this memory.

fn size(&self) -> Pages

Returns the number of allocated wasm pages.

fn grow(&self, delta: Pages) -> Result<Pages, MemoryError>

Grow memory by the specified amount of wasm pages.

fn vmmemory(&self) -> NonNull<VMMemoryDefinition>

Return a VMMemoryDefinition for exposing the memory to compiled wasm code.

The pointer returned in VMMemoryDefinition must be valid for the lifetime of this memory.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors