pub trait Memory:
Debug
+ Send
+ Sync {
// Required methods
fn ty(&self) -> MemoryType;
fn style(&self) -> &MemoryStyle;
fn size(&self) -> Pages;
fn grow(&self, delta: Pages) -> Result<Pages, MemoryError>;
fn vmmemory(&self) -> NonNull<VMMemoryDefinition>;
}Expand description
Trait for implementing Wasm Memory used by Wasmer.
Required Methods
Sourcefn ty(&self) -> MemoryType
fn ty(&self) -> MemoryType
Returns the memory type for this memory.
Sourcefn style(&self) -> &MemoryStyle
fn style(&self) -> &MemoryStyle
Returns the memory style for this memory.
Sourcefn grow(&self, delta: Pages) -> Result<Pages, MemoryError>
fn grow(&self, delta: Pages) -> Result<Pages, MemoryError>
Grow memory by the specified amount of wasm pages.
Sourcefn vmmemory(&self) -> NonNull<VMMemoryDefinition>
fn vmmemory(&self) -> NonNull<VMMemoryDefinition>
Return a VMMemoryDefinition for exposing the memory to compiled wasm code.
The pointer returned in VMMemoryDefinition must be valid for the lifetime of this memory.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".